==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/advance/WSCprocessBox.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCPROCESSBOX_H
#define WSCPROCESSBOX_H

#include <WScom.h>
#include <advance/WSCmessageBox.h>

class WSCscrForm;
class WSCvbtn;
class WSCvlabel;
class WSCform;
class WSCvlabel;
class WSCoption;
class WSCmessageBox;
class WSCvtoggle;
class WSCvifield;
class WSCindexForm;
class WSDmessage;
class WSDexecute;

class WSCprocessBox  :public WSCmessageBox {

  protected:
    char* _file_name;
    char* _dir_name;
    WSDexecute* _execute;
#if 0
     long _pid;
     WSDmessage* _m1;
     WSDmessage* _m2;
     WSDmessage* _m3;
     WSDmessage* _m4;
#endif
     WSCstring _str;
     unsigned _started:1;

     WSMFpropertyDef( WSNfileName,    char*,      _file_name ); 
     WSMFpropertyDef( WSNdirName,    char*,      _dir_name ); 
static void _receive_proc(WSDexecute*);
#if 0
static void _cb1(char*,void*);
static void _cb2(char*,void*);
static void _cb3(char*,void*);
static void _cb4(char*,void*);
#endif
    virtual void onActivate();

  public:
    WSCprocessBox(WSCbase*,char*);
    virtual ~WSCprocessBox();
    virtual long initialize();

    long start();
    long stop();
    void* getHandle();
    WSMFguiClassDef(WSCprocessBox,WSCmessageBox);
};
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/advance/WSCprocessBox.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCPROCESSBOX_H
#define WSCPROCESSBOX_H

#include <WScom.h>
#include <advance/WSCmessageBox.h>

class WSCscrForm;
class WSCvbtn;
class WSCvlabel;
class WSCform;
class WSCvlabel;
class WSCoption;
class WSCmessageBox;
class WSCvtoggle;
class WSCvifield;
class WSCindexForm;
class WSDmessage;
class WSDexecute;

class WSCprocessBox  :public WSCmessageBox {

  protected:
    char* _file_name;
    char* _dir_name;
    WSDexecute* _execute;
#if 0
     long _pid;
     WSDmessage* _m1;
     WSDmessage* _m2;
     WSDmessage* _m3;
     WSDmessage* _m4;
#endif
     WSCstring _str;
     unsigned _started:1;

     WSMFpropertyDef( WSNfileName,    char*,      _file_name ); 
     WSMFpropertyDef( WSNdirName,    char*,      _dir_name ); 
static void _receive_proc(WSDexecute*);
#if 0
static void _cb1(char*,void*);
static void _cb2(char*,void*);
static void _cb3(char*,void*);
static void _cb4(char*,void*);
#endif
    WSDLEX32 virtual void onActivate();

  public:
    WSDLEX32 WSCprocessBox(WSCbase*,char*);
    WSDLEX32 virtual ~WSCprocessBox();
    WSDLEX32 virtual long initialize();

    WSDLEX32 long start();
    WSDLEX32 long stop();
    WSDLEX32 void* getHandle();
    WSMFguiClassDef(WSCprocessBox,WSCmessageBox);
};
#endif
